==> plantuml-libs-7.1.0.tgz: package/distribution/fontawesome-6/Solid/PersonArrowUpFromLine.md <==
# PersonArrowUpFromLine


```text
fontawesome-6/Solid/PersonArrowUpFromLine
```

```text
include('fontawesome-6/Solid/PersonArrowUpFromLine')
```



| Illustration | PersonArrowUpFromLine |
| :---: | :---: |
| ![illustration for Illustration](../../fontawesome-6/Solid/PersonArrowUpFromLine.png) | ![illustration for PersonArrowUpFromLine](../../fontawesome-6/Solid/PersonArrowUpFromLine.Local.png) |




## PersonArrowUpFromLine

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('fontawesome-6/bootstrap')

' loads the Item which embeds the element PersonArrowUpFromLine
include('fontawesome-6/Solid/PersonArrowUpFromLine')

' renders the element
PersonArrowUpFromLine('PersonArrowUpFromLine', 'Person Arrow Up From Line', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('fontawesome-6/bootstrap')

' loads the Item which embeds the element PersonArrowUpFromLine
include('fontawesome-6/Solid/PersonArrowUpFromLine')

' renders the element
PersonArrowUpFromLine('PersonArrowUpFromLine', 'Person Arrow Up From Line', 'an optional tech label')
@enduml
```

==> plantuml-libs-9.1.0.tgz: package/distribution/fontawesome-6/Solid/PersonArrowUpFromLine.md <==
# PersonArrowUpFromLine


```text
fontawesome-6/Solid/PersonArrowUpFromLine
```

```text
include('fontawesome-6/Solid/PersonArrowUpFromLine')
```



| Illustration | PersonArrowUpFromLine |
| :---: | :---: |
| ![illustration for Illustration](../../fontawesome-6/Solid/PersonArrowUpFromLine.png) | ![illustration for PersonArrowUpFromLine](../../fontawesome-6/Solid/PersonArrowUpFromLine.Local.png) |




## PersonArrowUpFromLine

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('fontawesome-6/bootstrap')

' loads the Item which embeds the element PersonArrowUpFromLine
include('fontawesome-6/Solid/PersonArrowUpFromLine')

' renders the element
PersonArrowUpFromLine('PersonArrowUpFromLine', 'Person Arrow Up From Line', 'an optional tech label', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('fontawesome-6/bootstrap')

' loads the Item which embeds the element PersonArrowUpFromLine
include('fontawesome-6/Solid/PersonArrowUpFromLine')

' renders the element
PersonArrowUpFromLine('PersonArrowUpFromLine', 'Person Arrow Up From Line', 'an optional tech label', 'an optional description')
@enduml
```
